@@ -1,13 +1,13 @@
 #    _____           ______  _____ 
 #  / ____/    /\    |  ____ |  __ \
 # | |        /  \   | |__   | |__) | Caer - Modern Computer Vision
-# | |       / /\ \  |  __|  |  _  /  Languages: Python, C, C++
+# | |       / /\ \  |  __|  |  _  /  Languages: Python, C, C++, Cuda
 # | |___   / ____ \ | |____ | | \ \  http://github.com/jasmcaus/caer
 #  \_____\/_/    \_ \______ |_|  \_\
 
 # Licensed under the MIT License <http://opensource.org/licenses/MIT>
 # SPDX-License-Identifier: MIT
-# Copyright (c) 2020-21 The Caer Authors <http://github.com/jasmcaus>
+# Copyright (c) 2020-2021 The Caer Authors <http://github.com/jasmcaus>
 
 
 import cv2 as cv
@@ -38,7 +38,7 @@ __all__ = [
 def median(arr, axis=None):
     return np.median(arr, axis=axis)
 
-
+ 
 def mean(image, mask=None):
     try:
         return cv.mean(image, mask=mask)
@@ -52,30 +52,6 @@ def merge(tens):
 
     return cv.merge(tens)
 
-
-def split(tens):
-    try:
-        return cv.split(tens)
-    except:
-        raise ValueError('mean() expects an image')
-    
-
-def npmean(arr):
-    return np.mean(arr)
-
-
-def array(obj, dtype=None, order='K'):
-    return np.array(obj, dtype=dtype, order=order)
-
-
-def to_array(obj, dtype=None, order='K'):
-    return np.array(obj, dtype=dtype, order=order)
-
-
-def asarray(obj, dtype=None, order=None):
-    return np.asarray(obj, dtype=dtype, order=order)
-
-
 def get_classes_from_dir(DIR, verbose=0):
     if len(listdir(DIR, verbose=0)) == 0:
         raise ValueError('The specified directory does not seem to have any folders in it')
@@ -104,9 +80,6 @@ def train_val_split(X, y, val_ratio=.2):
     data = [] 
     for i in range(len(X)):
         data.append([X[i], y[i]])
-    
-    # import random
-    # random.shuffle(data)
 
     split = int(len(X) - (len(X) * val_ratio)) - 1
 
@@ -116,6 +89,8 @@ def train_val_split(X, y, val_ratio=.2):
     X_train, y_train = _sep(data_train)
     X_val, y_val = _sep(data_test)
 
+    del data
+
     return X_train, X_val, y_train, y_val
 
 
@@ -161,25 +136,4 @@ def edges(tens, threshold1=None, threshold2=None, use_median=True, sigma=None):
     else:
         canny_edges = cv.Canny(tens, threshold1, threshold2)
 
-    return canny_edges
-
-
-# def energy_map(tens):
-#     tens = bgr_to_gray(tens.astype(np.uint8))
-
-#     dx = cv.Sobel(tens, cv.CV_16S, 1, 0, ksize=3)
-#     abs_x = cv.convertScaleAbs(dx)
-#     dy = cv.Sobel(tens, cv.CV_16S, 0, 1, ksize=3)
-#     abs_y = cv.convertScaleAbs(dy)
-#     output = cv.addWeighted(abs_x, 0.5, abs_y, 0.5, 0)
-
-#     return output
-
-
-# def color_map(tens):
-#     gray_tens = bgr_to_gray(tens) 
-
-#     heatmap = cv.applyColorMap(gray_tens, 11)
-#     superimpose = cv.addWeighted(heatmap, 0.7, tens, 0.3, 0)
-
-#     return superimpose
\ No newline at end of file
+    return canny_edges
\ No newline at end of file
