@@ -1,10 +1,12 @@
 #    _____           ______  _____ 
 #  / ____/    /\    |  ____ |  __ \
 # | |        /  \   | |__   | |__) | Caer - Modern Computer Vision
-# | |       / /\ \  |  __|  |  _  /  Languages: Python, C, C++
+# | |       / /\ \  |  __|  |  _  /  Languages: Python, C, C++, Cuda
 # | |___   / ____ \ | |____ | | \ \  http://github.com/jasmcaus/caer
 #  \_____\/_/    \_ \______ |_|  \_\
 
 # Licensed under the MIT License <http://opensource.org/licenses/MIT>
 # SPDX-License-Identifier: MIT
-# Copyright (c) 2020-21 The Caer Authors <http://github.com/jasmcaus>
\ No newline at end of file
+# Copyright (c) 2020-2021 The Caer Authors <http://github.com/jasmcaus>
+
+from .annotations import *
\ No newline at end of file
