@@ -1,13 +1,13 @@
 #    _____           ______  _____ 
 #  / ____/    /\    |  ____ |  __ \
 # | |        /  \   | |__   | |__) | Caer - Modern Computer Vision
-# | |       / /\ \  |  __|  |  _  /  Languages: Python, C, C++
+# | |       / /\ \  |  __|  |  _  /  Languages: Python, C, C++, Cuda
 # | |___   / ____ \ | |____ | | \ \  http://github.com/jasmcaus/caer
 #  \_____\/_/    \_ \______ |_|  \_\
 
 # Licensed under the MIT License <http://opensource.org/licenses/MIT>
 # SPDX-License-Identifier: MIT
-# Copyright (c) 2020-21 The Caer Authors <http://github.com/jasmcaus>
+# Copyright (c) 2020-2021 The Caer Authors <http://github.com/jasmcaus>
 
 
 from .stream import Stream
@@ -19,7 +19,7 @@ __all__ = [
 ]
 
 
-def count_frames(video_path=None):
+def count_frames(video_path):
     r"""
         Returns the number of frames in a video at ``video_path``.
 
@@ -56,4 +56,5 @@ def get_fps(video_path=None):
     stream = Stream(video_path)
     fps_count = stream.get_fps()
     stream.release()
+    
     return fps_count
\ No newline at end of file
