@@ -1,13 +1,13 @@
 #    _____           ______  _____ 
 #  / ____/    /\    |  ____ |  __ \
 # | |        /  \   | |__   | |__) | Caer - Modern Computer Vision
-# | |       / /\ \  |  __|  |  _  /  Languages: Python, C, C++
+# | |       / /\ \  |  __|  |  _  /  Languages: Python, C, C++, Cuda
 # | |___   / ____ \ | |____ | | \ \  http://github.com/jasmcaus/caer
 #  \_____\/_/    \_ \______ |_|  \_\
 
 # Licensed under the MIT License <http://opensource.org/licenses/MIT>
 # SPDX-License-Identifier: MIT
-# Copyright (c) 2020-21 The Caer Authors <http://github.com/jasmcaus>
+# Copyright (c) 2020-2021 The Caer Authors <http://github.com/jasmcaus>
 
 
 from threading import Thread
@@ -21,7 +21,7 @@ from .constants import (
     FPS, FRAME_COUNT, FRAME_HEIGHT, FRAME_WIDTH
 )
 from ..jit.annotations import Tuple
-from ..adorad import Tensor
+from ..coreten import Tensor
 
 __all__ = [
     'Stream'
